@@ -211,7 +211,7 @@ static int blz[MAX_BLZ_CNT_AT],blz2[MAX_BLZ_CNT_AT],blz_idx[MAX_BLZ_CNT_AT],prue
 
 static unsigned long global_vars_initialized,init_in_progress;
 
-const static int w[17][11]={
+const static int w[18][11]={
       {0,0,0,0,0,0,0,0,0,0,0},  /* 0 */
       {1,2,1,2,1,2,1,2,1,2,1},  /* 1 */
       {1,2,3,4,5,6,7,2,3,4,5},  /* 2 */
@@ -228,7 +228,8 @@ const static int w[17][11]={
       {0,0,0,1,2,3,4,5,6,0,0},  /* D */
       {1,9,3,7,5,4,8,2,6,0,0},  /* E */
       {0,0,0,1,2,1,2,1,2,1,2},  /* F */
-      {0,0,0,1,2,3,4,5,6,7,2}   /* G */
+      {0,0,0,1,2,3,4,5,6,7,2},  /* G */
+      {0,1,2,6,5,7,4,8,3,9,2}   /* H */
    };
 
    /* die beiden Arrays char2num und char2numi dienen zur einfachen Umwandlung
@@ -245,7 +246,7 @@ const static int w[17][11]={
     * 1. Stelle                    1...9, A, B       1  
     * Anzahl Stellen               1...9, A, B       2  
     * Position der Prfziffer      1...9, A, B       4  
-    * Gewichtung                   0...9, A...G      8  
+    * Gewichtung                   0...9, A...H      8  
     * Rechenvorgang                0...8            16  
     */
 
@@ -253,15 +254,15 @@ const static int char2num[]={0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9,0,0,0,0,0,0,0,
    10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,
    0,0,0,0,0,0,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,
-   32,33,34,35,0,0,0,0,0,},
+   32,33,34,35,0,0,0,0,0,}, 
 char2numi[]={0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,10,9,8,7,6,5,4,3,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,},
-parameter_valid[]={16,22,22,22,22,22,22,22,22,6,6,6,0,0,0,0,0,
+parameter_valid[]={20,22,22,22,22,22,22,22,22,6,6,2,0,0,0,0,0,
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,9,9,9,9,9,9,9,
-   9,8,0,0,0,0,0,0,0,8,8,8,8,8,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
-   0,0,8,8,8,8,8,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,};
+   9,9,0,0,0,0,0,0,0,9,9,8,8,8,8,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
+   0,0,9,9,8,8,8,8,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,};
 
 
 /* Funktion adler32()+1 */
@@ -516,7 +517,7 @@ static int search_blz_idx(int such_blz)
 /* Vorspann  +2 */
 DLL_EXPORT int generate_lut_at(char *inputname,char *outputname,char *plain_name,char *plain_format)
 {
-   int i,j,k,cnt,idx,t_idx,ident1=0,ident2,last_blz,last_table,ld,show_all,sort_mode,file_version;
+   int i,j,k,idx,t_idx,ident1=0,ident2,last_blz,last_table,ld,show_all,sort_mode,file_version;
    int *table_idx;
    UINT4 adler;
    long adler_pos;
@@ -699,7 +700,8 @@ DLL_EXPORT int generate_lut_at(char *inputname,char *outputname,char *plain_name
    qsort(blz_idx,idx,sizeof(int),cmp_blz);
    blz_anzahl=idx;
 
-#define ADLER_FPRINTF fprintf(out,"%s",buffer); adler=adler32(adler,(signed char *)buffer,strlen(buffer))
+#define ADLER_FPRINTF fprintf(out,"%s",buffer); adler=adler32(adler,(signed char *)buffer,strlen(buffer)); x_sz+=strlen(buffer)
+{  int x_sz=0;
 
       /* Ausgabedatei schreiben: Kopfdaten (beide Dateiformate) +2 */
    adler=adler32(0,NULL,0);
@@ -734,10 +736,12 @@ DLL_EXPORT int generate_lut_at(char *inputname,char *outputname,char *plain_name
       fprintf(plain,"%s\n\n",ptr);
    }
 
+fprintf(stderr,"x_sz0: %d\n",x_sz);
       /* Ausgabedatei schreiben: Bankdaten (Binrdatei) +2 */
    eptr=UCP buffer+65536;
    uptr=UCP buffer;
    for(i=0,last_blz=last_table=-1;i<idx;i++){
+if(!((i+1)%50))fprintf(stderr,"x_sz1: %d\n",(int)((uptr-(unsigned char*)buffer)+1));
       j=blz_idx[i];
       if(blz[j]!=last_blz || pruef_tabelle[j]!=last_table){
          UM2C(blz[j]);
@@ -778,18 +782,29 @@ DLL_EXPORT int generate_lut_at(char *inputname,char *outputname,char *plain_name
          last_blz=blz[j];
          last_table=pruef_tabelle[j];
          if(uptr>eptr){
-            cnt=fwrite(buffer,1,(uptr-(unsigned char *)buffer)+1,out);
+            fwrite(buffer,1,(uptr-(unsigned char *)buffer)+1,out);
             adler=adler32(adler,(signed char *)buffer,(uptr-(unsigned char *)buffer)+1);
+fprintf(stderr,"x_sz1: %d\n",x_sz);
+x_sz+=(int)(uptr-(unsigned char*)buffer)+1;
+fprintf(stderr,"x_sz2: %d\n",x_sz);
             uptr=UCP buffer;
          }
       }
    }
-   cnt=fwrite(buffer,1,(uptr-(unsigned char *)buffer)+1,out);
+fprintf(stderr,"x_sz2: %d\n",(int)((uptr-(unsigned char*)buffer)+1));
+   fwrite(buffer,1,(uptr-(unsigned char *)buffer)+1,out);
+fprintf(stderr,"x_sz3: %d\n",(int)((uptr-(unsigned char*)buffer)+1));
    adler=adler32(adler,(signed char *)buffer,(uptr-(unsigned char *)buffer)+1);
+fprintf(stderr,"x_sz4: %d\n",(int)((uptr-(unsigned char*)buffer)+1));
+fprintf(stderr,"x_sz3: %d / %d\n",x_sz,(int)(uptr-(unsigned char*)buffer)+1);
+x_sz+=(int)(uptr-(unsigned char*)buffer)+1;
+fprintf(stderr,"x_sz4: %d\n",x_sz);
    fseek(out,adler_pos,SEEK_SET);
    fprintf(out,"%08lx\n",(unsigned long)adler);
+fprintf(stderr,"adler gen: %08x, sz: %d\n",adler,x_sz);
    fclose(in);
    fclose(out);
+}
 
       /* Ausgabedatei schreiben: Bankdaten (Plaindatei) +2 */
    if(plain){
@@ -968,6 +983,9 @@ static int read_lut(char *lut_name)
          for(dptr=ptr+7,i=0;i<8;i++)*dptr++='0';
          adler=adler32(0,NULL,0);
          adler=adler32(adler,(signed char *)buffer,size);
+#if 0
+fprintf(stderr,"size: %d, buflen: %d,adler: %08x, adler-file: %08x\n",size,strlen(buffer),adler,adler_file);
+#endif
          if(adler!=adler_file)return LUT_CRC_ERROR;
       }
    }
@@ -1724,8 +1742,7 @@ DLL_EXPORT int konto_check_at_version_release(void)
 int main(int argc,char **argv)
 {
    char *blz1,*kto1,*extra,*ptr,buffer[1024],*plain_name,*plain_format,*lut_name;
-   int retval,size,i,j;
-   long loeschdatum;
+   int retval;
    FILE *in,*out;
 
    if(argc<3 || !strcmp(argv[1],"-h") || !strcmp(argv[1],"-help") || !strcmp(argv[1],"--help")){
